@@ -15,7 +15,8 @@ AboutDialog::AboutDialog(QWidget *pParent)
     connect(&m_DoneBtn,SIGNAL(clicked()),SLOT(OnDoneBtn()));
 
     m_MainLayout.addWidget(&m_Icon,0,0,1,1,Qt::AlignTop);
-    m_MainLayout.addWidget(&m_TextContent,0,1,1,-1);
+    m_MainLayout.addWidget(&m_TextContent,0,1,2,-1);
+    m_MainLayout.addWidget(&m_BottomIcon,1,0,1,1,Qt::AlignLeft);
     m_MainLayout.addWidget(&m_DoneBtn,2,2);
     m_MainLayout.setRowStretch(2,50);
 
@@ -32,7 +33,7 @@ void AboutDialog::setText(const QString& text)
     m_TextContent.setText(text);
 }
 
-void AboutDialog::setIcon(const QString& iconPath)
+void AboutDialog::setTopIcon(const QString& iconPath)
 {
     //set about dialog icon
     QPixmap appIconMap;
@@ -40,6 +41,14 @@ void AboutDialog::setIcon(const QString& iconPath)
     m_Icon.setPixmap(appIconMap); //assign the icon pixmap
 }
 
+ void AboutDialog::setBottomIcon(const QString& iconPath)
+ {
+     //set about dialog bottom icon
+     QPixmap appIconMap;
+     appIconMap.load(iconPath); //load application icon from file
+     m_BottomIcon.setPixmap(appIconMap); //assign the icon pixmap
+ }
+
 void AboutDialog::OnDoneBtn()
 {
     //done button clicked handler (close dialog)
