@@ -103,6 +103,7 @@ MainWindow::MainWindow(QWidget *parent)
 
     //init the playlist listview instance
     m_pPlaylistView = new QListView(this);
+    //m_pPlaylistView->setContextMenuPolicy(Qt::CustomContextMenu);
     m_pPlaylistModel = new QStandardItemModel(this);
     m_pPlaylistDelegate = new ListViewDelegate(this);
     m_pPlaylistDelegate->setSubHeaderFontPointSize(14);
@@ -122,6 +123,7 @@ MainWindow::MainWindow(QWidget *parent)
     connect(m_pSession,SIGNAL(playbackPositionUpdated(qint64)),SLOT(OnPlaybackPositionUpdated(qint64)));
     connect(m_pSession,SIGNAL(playTokenLost()),SLOT(OnPlaybackTokenLost()),Qt::QueuedConnection);
     connect(m_pPlaylistView,SIGNAL(activated(QModelIndex)),SLOT(OnPlaylistActivated(QModelIndex)));
+    connect(m_pPlaylistView,SIGNAL(customContextMenuRequested(QPoint)),SLOT(OnContextMenuRequested(QPoint)));
     connect(menuBar(),SIGNAL(triggered(QAction*)),SLOT(OnMainMenuAction(QAction*)));
     connect(this,SIGNAL(showLogin()),SLOT(OnShowLogin()),Qt::QueuedConnection);
     connect(this,SIGNAL(handleLoginType()),SLOT(OnHandleLoginType()),Qt::QueuedConnection);
@@ -200,7 +202,7 @@ void MainWindow::OnSpotifyLogin(const QString& strUserID, const QString& strPass
         }
         else
         { //try to use remembered credentials (automatic login)
-            m_pSession->login(m_pAppSettings->value("QSpot/UserID","").toString(),m_pAppSettings->value("QSpot/Password","").toString());
+            m_pSession->login(m_pAppSettings->value("QSpot/UserID","").toString(),m_pAppSettings->value("QSpot/Password","").toString(),saveCredentials);
         }
     }
     else
@@ -493,11 +495,12 @@ void MainWindow::logout()
     m_pAppSettings->setValue("QSpot/SaveCredentials",0);
     m_pAppSettings->setValue("QSpot/UserID","");
     m_pAppSettings->setValue("QSpot/Password","");
-    close(); //close application
+    m_pSession->logout(); //logout current user
 }
 
 void MainWindow::closeEvent(QCloseEvent *)
 {//event received upon application shutdown
+    //m_pSession->logout(); //logout current user
     m_pSession->logout(); //logout current user
 }
 
@@ -932,6 +935,10 @@ void MainWindow::OnLoggedOut()
         qDebug() << "Logged out, reconnecting to Spotify..";
         m_pSession->relogin(); //try to re-connect to Spotify using current session credentials
     }
+    else
+    {
+        close(); //close down application on explicit logout request
+    }
 }
 
 void MainWindow::OnSpotifyReconnectRequired()
@@ -945,3 +952,17 @@ void MainWindow::OnSpotifyReconnectRequired()
         m_pSession->logout(); //logout the current user, before initiating new login
     }
 }
+
+void MainWindow::OnContextMenuRequested(QPoint pnt)
+{
+    //Start offline sync. for selected playlist (long press on playlist)
+    Q_UNUSED(pnt);
+
+    Spotify::Playlist* pPlaylist = m_Playlists.at(m_pPlaylistView->currentIndex().row());
+
+    if(pPlaylist)
+    {
+         qDebug() << "Starting offline sync of playlist:" << pPlaylist->getName();
+        m_pSession->setPlaylistOfflineMode(pPlaylist,true);
+    }
+}
