@@ -104,6 +104,9 @@ void Spotify::Session::init(const sp_bitrate& bitrate)
         qDebug() << "FATAL ERROR: Could not initiate session";
     }
 
+   //sp_session_set_connection_rules(m_session,SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI);
+   //p_session_set_connection_type(m_session,SP_CONNECTION_TYPE_NONE);
+
    sp_session_preferred_bitrate(m_session, bitrate); //set the preferred streaming bitrate
 
     m_ProcessEvents = false; //event processing not initiated
@@ -334,11 +337,12 @@ Spotify::Error Spotify::Session::play( Spotify::Track* track, bool preBuffer )
     m_buffering = false;
     Spotify::Error error;
 
-    if(m_currentTrack)
+   /* if(m_currentTrack)
     {//if track loaded; unload it first
         sp_session_player_unload(m_session);
         m_currentTrack = NULL;
     }
+    */
 
 
     // Disregard tracks that are not available:
@@ -516,8 +520,8 @@ Spotify::Error Spotify::Session::getPlaylists()
   //get the playlists
  Spotify::Error error;
 
- m_ProcessEvents = false;
- m_DisableNotifyThread = true;
+ //m_ProcessEvents = false;
+ //m_DisableNotifyThread = true;
 
  m_bPlaylistsLoading = true;
 
@@ -613,7 +617,6 @@ void Spotify::Session::updatePlaylistsMetadataSlot()
         }
     }
 
-
     // Try to load searches:
     QList<Spotify::Search*> searches = m_searchHash.values();
     for( int i = 0; i < searches.count(); ++i )
@@ -1376,3 +1379,46 @@ void Spotify::Session::endOfTrackWrapper()
     }
 }
 
+void Spotify::Session::streamingError( sp_session* session, sp_error error )
+{
+    Q_UNUSED(session);
+    Spotify::Session::callingSession->streamingErrorWrapper(error);
+}
+
+void Spotify::Session::streamingErrorWrapper(sp_error error)
+{
+    Spotify::Error err(error);
+
+    qDebug() << "Streaming error: " << err.toString();
+}
+
+void Spotify::Session::setPlaylistOfflineMode(Spotify::Playlist* pPlaylist, bool offline)
+{
+    //Set whether the specified playlist should be synchronised for offline usage (in case offline is set to true
+    //the playlist will be made available offline; in case offline is false, the playlist will be made unavailable in offline mode)
+
+    if(pPlaylist)
+    {
+        sp_playlist_set_offline_mode(m_session, pPlaylist->getPlaylist(), offline);
+    }
+}
+
+void Spotify::Session::offlineStatusUpdated( sp_session* session )
+{
+    Q_UNUSED(session);
+    Spotify::Session::callingSession->offlineStatusUpdatedWrapper();
+}
+
+void Spotify::Session::offlineStatusUpdatedWrapper()
+{
+    qDebug() << "Offline synchronisation status updated..";
+
+    sp_offline_sync_status offlineStatus;
+
+    if(sp_offline_sync_get_status(m_session,&offlineStatus)) //get offline sync status
+    {
+        qDebug() << "Copied tracks: " << offlineStatus.copied_tracks << " / queued tracks: "  << offlineStatus.queued_tracks;
+        //emit offlineSyncStatusUpdated(offlineStatus.copied_tracks,offlineStatus.queued_tracks);
+    }
+}
+
