@@ -197,6 +197,15 @@ namespace Spotify
              */
             bool movePlaylist( const int index, int position );
 
+            /**
+
+             * Set whether the specified playlist should be synchronised for offline usage.
+             * @param pPlaylist playlist to be made available / unavailable in offline mode
+             * @param offline true in case playlist should be made available in offline mode; otherwise set to false
+             */
+            void setPlaylistOfflineMode(Spotify::Playlist* pPlaylist, bool offline);
+
+
             /**
              * Browse an artist.
              * @param artist Artist to be browsed. The artist metadata does not have to be loaded.
@@ -282,6 +291,10 @@ namespace Spotify
 
             static void SP_CALLCONV endOfTrackCallback( sp_session* session );
 
+            static void SP_CALLCONV streamingError( sp_session* session, sp_error error );
+
+            static void SP_CALLCONV offlineStatusUpdated( sp_session* session);
+
 
         public slots:
 
@@ -585,6 +598,10 @@ namespace Spotify
 
             void endOfTrackWrapper();
 
+            void streamingErrorWrapper(sp_error error);
+
+            void offlineStatusUpdatedWrapper();
+
             /* returns true in case all playlist containers have been completely loaded and added to internal playlists list */
             bool isPlaylistContainersReady();
 
